"""
Horcrux: Split your files into encrypted fragments using Shamir's Secret Sharing Scheme.

This package provides a simple yet powerful way to encrypt and split files into
multiple fragments (horcruxes) where only a subset is needed to reconstruct the
original file.
"""

from setuptools import setup

# Configuration is in pyproject.toml
setup()
